package com.ynet.life.action;

import com.ynet.gene.core.Context;
import com.ynet.gene.core.GENEException;
import com.ynet.life.base.LifeAction;
import com.ynet.life.base.Trace;
import com.ynet.life.exception.TranFailException;
import java.text.DecimalFormat;
import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.Calendar;
import java.util.Date;

/* loaded from: com_ynet_life_action.jar:com/ynet/life/action/RemainTimes.class */
public class RemainTimes extends LifeAction {
    private String cycleField = null;
    private String monthDayField = null;
    private String weekDayField = null;
    private String endDateField = null;
    private String nextDateField = null;
    private String remainTimesField = null;
    private String limitAMTField = null;
    private String executeTimeField = null;
    private String AMTField = null;

    public String execute(Context context) throws GENEException {
        String remainTimes;
        try {
            String cycle = (String) context.getDataValue(this.cycleField);
            String monthDay = (String) context.getDataValue(this.monthDayField);
            context.getDataValue(this.weekDayField);
            String nextDate = (String) context.getDataValue(this.nextDateField);
            String endDate = (String) context.getDataValue(this.endDateField);
            String limitAMT = (String) context.getDataValue(this.limitAMTField);
            String executeTime = (String) context.getDataValue(this.executeTimeField);
            String AMT = (String) context.getDataValue(this.AMTField);
            switch (Integer.parseInt(cycle)) {
                case 0:
                    remainTimes = getTimeByDay(nextDate, endDate);
                    break;
                case 1:
                    remainTimes = getTimeByWeek(nextDate, endDate);
                    break;
                case 2:
                    remainTimes = getTimeByMonth(nextDate, endDate, monthDay);
                    break;
                default:
                    Trace.logDebug("LifeAction", "计算未执行次数出错");
                    throw new TranFailException("GENEException");
            }
            DecimalFormat fm = new DecimalFormat("#");
            if (limitAMT != null) {
                String timesByLimitAMT = fm.format(Double.parseDouble(limitAMT) / Double.parseDouble(AMT));
                if (Integer.parseInt(timesByLimitAMT) < Integer.parseInt(remainTimes)) {
                    remainTimes = timesByLimitAMT;
                }
            }
            if (executeTime != null && Integer.parseInt(executeTime) < Integer.parseInt(remainTimes)) {
                remainTimes = executeTime;
            }
            context.setDataValue(this.remainTimesField, remainTimes);
            return null;
        } catch (Exception e) {
            Trace.logDebug("LifeAction", "计算未执行次数出错");
            throw new GENEException(e);
        }
    }

    public String getTimeByDay(String nextDate, String endDate) throws GENEException {
        try {
            return Integer.toString(getTotal(nextDate, endDate) + 1);
        } catch (ParseException e) {
            Trace.logDebug("LifeAction", "计算未执行次数出错，周期类型为按每天");
            throw new GENEException(e);
        }
    }

    public String getTimeByMonth(String nextDate, String endDate, String monthDay) {
        String nextDate2;
        if (nextDate.substring(0, 4).equals(endDate.substring(0, 4))) {
            if (Integer.parseInt(endDate.substring(6, 8)) >= Integer.parseInt(nextDate.substring(6, 8))) {
                nextDate2 = Integer.toString((Integer.parseInt(endDate.substring(4, 6)) - Integer.parseInt(monthDay)) + 1);
            } else {
                nextDate2 = Integer.toString(Integer.parseInt(endDate.substring(4, 6)) - Integer.parseInt(monthDay));
            }
        } else {
            int firstMonths = 13 - Integer.parseInt(nextDate.substring(6, 8));
            int deadlineMonths = Integer.parseInt(endDate.substring(6, 8));
            int begin = Integer.parseInt(nextDate.substring(0, 4));
            int end = Integer.parseInt(endDate.substring(0, 4));
            nextDate2 = Integer.toString(((begin - end) * 12) + firstMonths + deadlineMonths);
        }
        return nextDate2;
    }

    public String getTimeByWeek(String nextDate, String endDate) throws GENEException {
        try {
            return Integer.toString((getTotal(nextDate, endDate) / 7) + 1);
        } catch (ParseException e) {
            Trace.logDebug("LifeAction", "计算未执行次数出错，周期类型为按星期");
            throw new GENEException(e);
        }
    }

    public int getTotal(String firstTime, String deadline) throws ParseException {
        int i;
        SimpleDateFormat sdf = new SimpleDateFormat("yyyyMMdd");
        Calendar now = Calendar.getInstance();
        Date date = sdf.parse(firstTime);
        now.setTime(date);
        int firstYearDays = now.get(6);
        Date date2 = sdf.parse(deadline);
        now.setTime(date2);
        int deadlineDays = now.get(6);
        if (firstTime.substring(0, 4).equals(deadline.substring(0, 4))) {
            i = deadlineDays - firstYearDays;
        } else {
            Date date3 = sdf.parse(String.valueOf(firstTime.substring(0, 4)) + "1231");
            now.setTime(date3);
            int firstDays = now.get(6) - firstYearDays;
            int begin = Integer.parseInt(firstTime.substring(0, 4));
            int end = Integer.parseInt(deadline.substring(0, 4));
            int midstDays = 0;
            for (int i2 = begin; i2 < end - 1; i2++) {
                Date date4 = sdf.parse(String.valueOf(Integer.toString(i2)) + "1231");
                now.setTime(date4);
                midstDays = now.get(6) + midstDays;
            }
            Date date5 = sdf.parse(String.valueOf(deadline.substring(0, 4)) + "1231");
            now.setTime(date5);
            i = firstDays + midstDays + deadlineDays;
        }
        return i;
    }

    public String getCycleField() {
        return this.cycleField;
    }

    public void setCycleField(String cycleField) {
        this.cycleField = cycleField;
    }

    public String getMonthDayField() {
        return this.monthDayField;
    }

    public void setMonthDayField(String monthDayField) {
        this.monthDayField = monthDayField;
    }

    public String getWeekDayField() {
        return this.weekDayField;
    }

    public void setWeekDayField(String weekDayField) {
        this.weekDayField = weekDayField;
    }

    public String getEndDateField() {
        return this.endDateField;
    }

    public void setEndDateField(String endDateField) {
        this.endDateField = endDateField;
    }

    public String getNextDateField() {
        return this.nextDateField;
    }

    public void setNextDateField(String nextDateField) {
        this.nextDateField = nextDateField;
    }

    public String getRemainTimesField() {
        return this.remainTimesField;
    }

    public void setRemainTimesField(String remainTimesField) {
        this.remainTimesField = remainTimesField;
    }

    public String getLimitAMTField() {
        return this.limitAMTField;
    }

    public void setLimitAMTField(String limitAMTField) {
        this.limitAMTField = limitAMTField;
    }

    public String getExecuteTimeField() {
        return this.executeTimeField;
    }

    public void setExecuteTimeField(String executeTimeField) {
        this.executeTimeField = executeTimeField;
    }

    public String getAMTField() {
        return this.AMTField;
    }

    public void setAMTField(String aMTField) {
        this.AMTField = aMTField;
    }
}
